# DataHyve CLI Client

[![YouTube](https://img.shields.io/badge/YouTube-Video-red?logo=youtube)](https://www.youtube.com/link-to-video)
[![Devpost](https://img.shields.io/badge/Devpost-Project-blue?logo=devpost)](https://devpost.com/link-to-project)
[![License](https://img.shields.io/badge/License-MIT-green)](./LICENSE)

<!-- markdownlint-disable-next-line -->
<div style="text-align: center; width: 100%;">
<!-- markdownlint-disable-next-line -->
    <img src="../assets/main-banner.png" alt="Logo Banner" style="width: 100%;"/>
</div>

Install the client, send data to a SQL DB, and visualize insights on a Streamlit dashboard. Query your servers for real-time analysis

## Author

[Aryan Khurana](https://github.com/AryanK1511)
